# eric7.WebBrowser.QtHelp.QtHelpDocumentationSelectionDialog

Module implementing a dialog to select QtHelp documentation sets to be installed.

### Global Attributes

None

### Classes

QtHelpDocumentationSelectionDialog | Class implementing a dialog to select QtHelp documentation sets to be installed.

### Functions

None

## QtHelpDocumentationSelectionDialog

Class implementing a dialog to select QtHelp documentation sets to be installed.

### Derived from

QDialog, Ui_QtHelpDocumentationSelectionDialog

### Class Attributes

AddMode
ManageMode

### Class Methods

None

### Methods

QtHelpDocumentationSelectionDialog | Constructor
__deleteCategory | Private method to delete a category.
getData | Public method to retrieve the selected help documents.
on_deleteAllButton_clicked | Private slot to delete all documentation sets.
on_deleteButton_clicked | Private slot to delete the selected documentation sets.
on_deleteCategoryButton_clicked | Private slot to delete the selected documentation set categories.
on_documentationList_itemSelectionChanged | Private slot handling the selection of items.

### Static Methods

None

#### QtHelpDocumentationSelectionDialog (Constructor)

QtHelpDocumentationSelectionDialog(helpDocuments, mode, parent=None)

Constructor

helpDocuments (dict of lists of str)
  dictionary containing the lists of help documents to be shown
mode (str)
  mode of the dialog
parent (QWidget)
  reference to the parent widget

#### QtHelpDocumentationSelectionDialog.__deleteCategory

__deleteCategory(category)

Private method to delete a category.

category (QTreeWidgetItem)
  reference to the category item

#### QtHelpDocumentationSelectionDialog.getData

getData()

Public method to retrieve the selected help documents.

Return:
  list of QtHelp documentation sets to be installed

Return Type:
  set of str

#### QtHelpDocumentationSelectionDialog.on_deleteAllButton_clicked

on_deleteAllButton_clicked()

Private slot to delete all documentation sets.

#### QtHelpDocumentationSelectionDialog.on_deleteButton_clicked

on_deleteButton_clicked()

Private slot to delete the selected documentation sets.

#### QtHelpDocumentationSelectionDialog.on_deleteCategoryButton_clicked

on_deleteCategoryButton_clicked()

Private slot to delete the selected documentation set categories.

#### QtHelpDocumentationSelectionDialog.on_documentationList_itemSelectionChanged

on_documentationList_itemSelectionChanged()

Private slot handling the selection of items.

Up